changeset 22685:a9f375bef470

(derived-mode-hooks-name): Use -hook, not -hooks, in mode hook name. (derived-mode-hook-name): Renamed from ...-hooks; caller changed.
author Richard M. Stallman <rms@gnu.org>
date Fri, 03 Jul 1998 21:37:43 +0000
parents f1cde5061b0b
children 96320770e3d5
files lisp/derived.el
diffstat 1 files changed, 7 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/derived.el	Fri Jul 03 21:37:22 1998 +0000
+++ b/lisp/derived.el	Fri Jul 03 21:37:43 1998 +0000
@@ -74,7 +74,7 @@
 ;;   default, but may be redefined by the user to contain special
 ;;   commands (ie. setting local variables like 'outline-regexp')
 ;;   **NOTE: do not use this option -- it will soon be obsolete.
 ;; - run anything assigned to 'hypertext-mode-hooks' (obsolete, but
 ;;   supported for the sake of compatibility).
 ;;
 ;; The advantages of this system are threefold.  First, text mode is
@@ -166,7 +166,7 @@
 ;;;					; any -- this will soon be
 ;;;					; obsolete.
 ;;;	 (derived-mode-run-setup-function '(, child))
 					; Run the hooks, if any.
 	 (derived-mode-run-hooks '(, child))))))
 
 
@@ -187,9 +187,9 @@
   "Construct a setup-function name based on a mode name."
   (intern (concat (symbol-name mode) "-setup")))
 
-(defsubst derived-mode-hooks-name (mode)
-  "Construct a hooks name based on a mode name."
-  (intern (concat (symbol-name mode) "-hooks")))
+(defsubst derived-mode-hook-name (mode)
+  "Construct the mode hook name based on mode name MODE."
+  (intern (concat (symbol-name mode) "-hook")))
 
 (defsubst derived-mode-map-name (mode)
   "Construct a map name based on a mode name."
@@ -293,9 +293,9 @@
 ;;;	(funcall fname))))
 
 (defun derived-mode-run-hooks (mode)
-  "Run the hooks if they exist."
+  "Run the mode hook for MODE."
 
-  (let ((hooks-name (derived-mode-hooks-name mode)))
+  (let ((hooks-name (derived-mode-hook-name mode)))
     (if (boundp hooks-name)
 	(run-hooks hooks-name))))
@@ -74,7 +74,7 @@
 ;;   commands (ie. setting local variables like 'outline-regexp')
 ;;   **NOTE: do not use this option -- it will soon be obsolete.
-;; - run anything assigned to 'hypertext-mode-hooks' (obsolete, but
+;; - run anything assigned to 'hypertext-mode-hook' (obsolete, but
 ;;   supported for the sake of compatibility).
 ;;
@@ -166,7 +166,7 @@
 ;;;					; obsolete.
 ;;;	 (derived-mode-run-setup-function '(, child))
-					; Run the hooks, if any.
+					; Run the hook, if any.
 	 (derived-mode-run-hooks '(, child))))))
 